function [a,b,c,e,h] = ParametrosElipse_JMS(dp,da)
% Solution to control 1, 2023/11/03
% Input:
%   dp : periastron of an elliptical orbit (min distance)
%   da : afoastron of an elliptical orbit (max distance)
% Output:
%   a  : major semi axis
%   b  : minos semi axis
%   c  : focal distance
%   e  : excentricity
%   h  : semi-latus rectum
% J.M.Soler

a = (dp+da)/2;
b = sqrt(dp.*da);
c = (da-dp)/2;
e = c./a;
h = b.^2./a;

end

